@@ -30,22 +30,26 @@ from preseem_grpc_model import metrics_pb2, metrics_pb2_grpc
 from preseem_grpc_model import network_metadata_pb2, network_metadata_pb2_grpc
 from preseem_grpc_model import company_configs_pb2, company_configs_pb2_grpc
 
+
 class ConfigType():
+
     def __init__(self, name, prefix, value, pb, grpc):
-        self.name = name    # the lowercase name of the enum
+        self.name = name  # the lowercase name of the enum
         self.value = value  # the int value of the enum
-        self.prefix = prefix # op prefix
-        self.pb = pb        # pb2 import
-        self.grpc = grpc    # pb2_grpc import
-        self.svc = None     # service stub
-        self.pb_type = None # grpc type
-        self.del_req = None # delete request
-        self.get_req = None # get request
-        self.set_req = None # set request
-        self.sub_req = None # subscribe request
+        self.prefix = prefix  # op prefix
+        self.pb = pb  # pb2 import
+        self.grpc = grpc  # pb2_grpc import
+        self.svc = None  # service stub
+        self.pb_type = None  # grpc type
+        self.del_req = None  # delete request
+        self.get_req = None  # get request
+        self.set_req = None  # set request
+        self.sub_req = None  # subscribe request
+
 
 class Subscription(object):
     """Helper class to manage a GRPC subscription."""
+
     def __init__(self, client, op, req, cbk):
         """
         Manage a GRPC subscription in asyncio.  Pass in the client object
@@ -72,7 +76,7 @@ class Subscription(object):
         retry = False
         while True:
             # Setup the subscription
-            syn=False
+            syn = False
             if self._iter is None:
                 try:
                     if retry:
@@ -84,7 +88,7 @@ class Subscription(object):
                     logging.warning('Error creating subscription: %s', e)
                     time.sleep(10)
                     continue
-                syn=True
+                syn = True
 
             try:
                 msg = self._iter.next()
@@ -92,19 +96,21 @@ class Subscription(object):
                 # https://grpc.io/grpc/python/grpc.html?highlight=method#grpc.StatusCode
                 # Disconnect, need to restart subscription.  Restart
                 # the initializing state after this.
-                if e.code() == grpc.StatusCode.CANCELLED and e.details() == 'Locally cancelled by application!':
+                if e.code() == grpc.StatusCode.CANCELLED and e.details(
+                ) == 'Locally cancelled by application!':
                     return  # cancelled by application
                 elif e.code() == grpc.StatusCode.NOT_FOUND:
                     # STM-4023 the thing we are subscribed to has gone away.
-                    logging.warning('GRPC NotFound error: %s, exit subscription', e.details())
+                    logging.warning('GRPC NotFound error: %s, exit subscription',
+                                    e.details())
                     break
-                logging.warning('GRPC ERROR: %s: %s for host: %s', e.code(), e.details(), self._client.host)
+                logging.warning('GRPC ERROR: %s: %s for host: %s', e.code(),
+                                e.details(), self._client.host)
                 logging.info('Reconnect to %s after 10s', self._client.host)
                 time.sleep(10)  # TODO Backoff
                 self._iter = None
                 continue
 
-
             except Exception as e:
                 print('Error reading from subscription iterator: {}'.format(e))
                 print(type(e))
@@ -128,6 +134,7 @@ class Subscription(object):
 
 class PreseemGrpcClient(object):
     """Implement the GRPC client to the Preseem API, adapted to asyncio."""
+
     def __init__(self, api_key, host=None, port=None):
         self.api_key = api_key
         self._executor = concurrent.futures.ThreadPoolExecutor(max_workers=10)
@@ -149,7 +156,8 @@ class PreseemGrpcClient(object):
                 cn = ctname.lower()
                 pmod = import_module(f'preseem_grpc_model.{cn}_pb2')
                 gmod = import_module(f'preseem_grpc_model.{cn}_pb2_grpc')
-                ct = self.config_types[ctid] = ConfigType(cn, cn.replace('_', ''), ctid, pmod, gmod)
+                ct = self.config_types[ctid] = ConfigType(cn, cn.replace('_', ''), ctid,
+                                                          pmod, gmod)
                 # assume naming conventions for the operations
                 capname = ''.join([x[:1].upper() + x[1:] for x in cn.split('_')])
                 ct.pb_type = getattr(pmod, f'{capname}')
@@ -190,7 +198,13 @@ class PreseemGrpcClient(object):
             pass
         return r
 
-    async def _grpc_op(self, op, req, num_retries=5, timeout=None, collect_results=None, metadata=None):
+    async def _grpc_op(self,
+                       op,
+                       req,
+                       num_retries=5,
+                       timeout=None,
+                       collect_results=None,
+                       metadata=None):
         loop = asyncio.get_event_loop()
         for retry_num in range(num_retries + 1):
             if retry_num > 0:
@@ -200,24 +214,41 @@ class PreseemGrpcClient(object):
                 if timeout:
                     try:
                         if collect_results:
-                            return await asyncio.wait_for(loop.run_in_executor(self._executor, self._grpc_op_collect, op, req, metadata), timeout=timeout)
+                            return await asyncio.wait_for(loop.run_in_executor(
+                                self._executor, self._grpc_op_collect, op, req,
+                                metadata),
+                                                          timeout=timeout)
                         else:
-                            return await asyncio.wait_for(loop.run_in_executor(self._executor, functools.partial(op, req, metadata=metadata)), timeout=timeout)
+                            return await asyncio.wait_for(loop.run_in_executor(
+                                self._executor,
+                                functools.partial(op, req, metadata=metadata)),
+                                                          timeout=timeout)
                     except asyncio.TimeoutError:
                         logging.warning('GRPC operation timed out: %s', op)
                         raise
                 else:
                     if collect_results:
-                        x = await loop.run_in_executor(self._executor, self._grpc_op_collect, op, req, metadata)
+                        x = await loop.run_in_executor(self._executor,
+                                                       self._grpc_op_collect, op, req,
+                                                       metadata)
                     else:
-                        x = await loop.run_in_executor(self._executor, functools.partial(op, req, metadata=metadata))
+                        x = await loop.run_in_executor(
+                            self._executor, functools.partial(op,
+                                                              req,
+                                                              metadata=metadata))
                     return x
             except grpc.RpcError as err:
-                logging.debug('Error calling service: %s (%s)', err.code(), err.details())
-                if err.code() in (grpc.StatusCode.INTERNAL, grpc.StatusCode.NOT_FOUND, grpc.StatusCode.UNKNOWN, grpc.StatusCode.UNIMPLEMENTED, grpc.StatusCode.INVALID_ARGUMENT, grpc.StatusCode.PERMISSION_DENIED):
+                logging.debug('Error calling service: %s (%s)', err.code(),
+                              err.details())
+                if err.code() in (grpc.StatusCode.INTERNAL, grpc.StatusCode.NOT_FOUND,
+                                  grpc.StatusCode.UNKNOWN,
+                                  grpc.StatusCode.UNIMPLEMENTED,
+                                  grpc.StatusCode.INVALID_ARGUMENT,
+                                  grpc.StatusCode.PERMISSION_DENIED):
                     raise
                 if retry_num == num_retries:
-                    logging.warning('Error calling service: %s (%s)', err.code(), err.details())
+                    logging.warning('Error calling service: %s (%s)', err.code(),
+                                    err.details())
                     raise
             except Exception as e:
                 logging.warning('%s error calling service: %s', type(e).__name__, e)
@@ -227,37 +258,49 @@ class PreseemGrpcClient(object):
 
     def _connect(self):
         """Connect to the server and authenticate. (blocking)"""
+
         class ApiKeyCallCredentials(grpc.AuthMetadataPlugin):
+
             def __init__(self, api_key):
                 self.api_key = api_key
+
             def __call__(self, context, callback):
-                callback((('api_key', self.api_key),), None)
+                callback((('api_key', self.api_key), ), None)
 
         dst = '{}:{}'.format(self.host, self.port)
         while self._nm_svc is None:
             try:
                 # STM-3013, STM-3115 make grpc connection robust
-                grpc_opts = [('grpc.keepalive_time_ms', 30000),   # send keepalive every 30s
-                             ('grpc.keepalive_timeout_ms', 15000), # keepalive ping timeout after 15s
-                             ('grpc.keepalive_permit_without_calls', True),  # send keepalives when no grpc calls
-                             ('grpc.http2.max_pings_without_data', 0)]  # allow unlimited pings without data
+                grpc_opts = [
+                    ('grpc.keepalive_time_ms', 30000),  # send keepalive every 30s
+                    ('grpc.keepalive_timeout_ms',
+                     15000),  # keepalive ping timeout after 15s
+                    ('grpc.keepalive_permit_without_calls',
+                     True),  # send keepalives when no grpc calls
+                    ('grpc.http2.max_pings_without_data', 0)
+                ]  # allow unlimited pings without data
                 if self.api_key:
-                    call_creds = grpc.metadata_call_credentials(ApiKeyCallCredentials(self.api_key))
+                    call_creds = grpc.metadata_call_credentials(
+                        ApiKeyCallCredentials(self.api_key))
                     try:
                         with open('/etc/pki/tls/certs/ca-bundle.crt', 'rb') as f:
                             ca_certs = f.read()
                     except:  # not fedora?  use default built-in CA bundle
                         ca_certs = None
                     ssl_creds = grpc.ssl_channel_credentials(root_certificates=ca_certs)
-                    channel_creds = grpc.composite_channel_credentials(ssl_creds, call_creds)
+                    channel_creds = grpc.composite_channel_credentials(
+                        ssl_creds, call_creds)
                     channel = grpc.secure_channel(dst, channel_creds, options=grpc_opts)
                 else:
                     channel = grpc.insecure_channel(dst, options=grpc_opts)
                 self._channel = channel
                 self._metrics_svc = metrics_pb2_grpc.NetworkMetricsStub(channel)
-                self._nm_svc = network_metadata_pb2_grpc.NetworkMetadataServiceStub(channel)
-                self._nm_ref_svc = network_metadata_pb2_grpc.NetworkMetadataReferenceServiceStub(channel)
-                self._config2_svc = company_configs_pb2_grpc.CompanyConfigsServiceStub(channel)
+                self._nm_svc = network_metadata_pb2_grpc.NetworkMetadataServiceStub(
+                    channel)
+                self._nm_ref_svc = network_metadata_pb2_grpc.NetworkMetadataReferenceServiceStub(
+                    channel)
+                self._config2_svc = company_configs_pb2_grpc.CompanyConfigsServiceStub(
+                    channel)
                 for ct in self.config_types.values():
                     cls = [x for x in dir(ct.grpc) if x[-4:] == 'Stub']
                     if cls:
@@ -274,7 +317,8 @@ class PreseemGrpcClient(object):
         """Block in this coroutine and call cbk as notifications arrive."""
         if not self._nm_svc:
             await self.connect()
-        req = network_metadata_pb2.NetworkMetadataSubscribeRequest(allow_ipv6_and_shorter_ipv4_prefixes=True)
+        req = network_metadata_pb2.NetworkMetadataSubscribeRequest(
+            allow_ipv6_and_shorter_ipv4_prefixes=True)
         req.do_not_resolve_references = not resolve
         if company_id:
             req.company_id = company_id
@@ -291,7 +335,8 @@ class PreseemGrpcClient(object):
         req = network_metadata_pb2.NetworkMetadataReferenceSubscribeRequest()
         if company_id:
             req.company_id = company_id
-        self._nm_ref_subscription = Subscription(self, self._nm_ref_svc.Subscribe, req, cbk)
+        self._nm_ref_subscription = Subscription(self, self._nm_ref_svc.Subscribe, req,
+                                                 cbk)
         try:
             await self._nm_ref_subscription.run()
         except asyncio.CancelledError:
@@ -358,12 +403,12 @@ class PreseemGrpcClient(object):
         if not ct.svc:
             await self.connect()
         req = ct.get_req()
-        req.company_id=company_id
+        req.company_id = company_id
         setattr(req, f'{ct.prefix}_id', config_id)
         r = await self._grpc_op(ct.svc.Get, req)
         if bool(r.success):
             return getattr(r, ct.prefix)
-        else: # probably a race where it was deleted before we could get it
+        else:  # probably a race where it was deleted before we could get it
             logging.warning('Failed to get %s config "%s"', ct.name, config_id)
             return None
 
@@ -374,7 +419,7 @@ class PreseemGrpcClient(object):
         if not ct.svc:
             await self.connect()
         req = ct.set_req()
-        req.company_id=company_id
+        req.company_id = company_id
         getattr(req, ct.prefix).CopyFrom(obj)
         r = await self._grpc_op(ct.svc.Set, req)
         return bool(r.success)
@@ -386,7 +431,7 @@ class PreseemGrpcClient(object):
         if not ct.svc:
             await self.connect()
         req = ct.del_req()
-        req.company_id=company_id
+        req.company_id = company_id
         setattr(req, f'{ct.prefix}_id', config_id)
         r = await self._grpc_op(ct.svc.Delete, req)
         return bool(r.success)
@@ -396,6 +441,7 @@ class PreseemGrpcClient(object):
         Subscribe to notifications for updates to a config instance.
         The callback takes args (company_id, config_type, message).
         """
+
         async def _cbk(msg, _):
             nonlocal company_id, config_type, cbk
             await cbk(company_id, config_type, msg)
@@ -406,7 +452,8 @@ class PreseemGrpcClient(object):
         req = ct.sub_req()
         req.company_id = company_id
         setattr(req, f'{ct.prefix}_id', config_id)
-        sub = self._cfg_subscriptions[config_id] = Subscription(self, ct.svc.Subscribe, req, _cbk)
+        sub = self._cfg_subscriptions[config_id] = Subscription(
+            self, ct.svc.Subscribe, req, _cbk)
         try:
             await sub.run()
         except asyncio.CancelledError:
