@@ -26,6 +26,14 @@ class ElementRole:
     CPE_RADIO = UUID('c72115d3-daf9-43ae-9475-083d62eae74f')
 
 
+_account_field_map = {
+    'type': lambda x: x.type,
+    'status': lambda x: x.status,
+    'company_name': lambda x: x.company_name,
+    'first_name': lambda x: x.first_name,
+    'last_name': lambda x: x.last_name,
+}
+
 _package_field_map = {
     'name': lambda x: x.name,
     'download_rate': lambda x: x.download_rate or None,
@@ -116,6 +124,7 @@ async def sync_preseem_model(preseem_model,
                              role,
                              items,
                              packages=None,
+                             accounts=None,
                              nm_model=None,
                              noact=False,
                              verbose=0):
@@ -138,7 +147,8 @@ async def sync_preseem_model(preseem_model,
         raise ValueError('source cannot be the empty string')
 
     async with sync_lock:
-        model_discs, model_sites, model_packages = await asyncio.gather(
+        model_accounts, model_discs, model_sites, model_packages = await asyncio.gather(
+            preseem_model.Account.List(company_uuid=company_uuid),
             preseem_model.Element.ListElementDiscovery(company_uuid=company_uuid,
                                                        intent_role_uuid=role.bytes),
             preseem_model.Site.List(company_uuid=company_uuid),
@@ -290,4 +300,34 @@ async def sync_preseem_model(preseem_model,
                                 _package_field_map,
                                 noact=noact)
 
+        if accounts is not None:
+            assert isinstance(accounts, dict)
+            for account in accounts.values():
+                if not isinstance(account.id, str) or account.id == '':
+                    raise ValueError('invalid string value for account source_id')
+                if account.type is not None and (not isinstance(account.type, int)
+                                                 or account.type <= 0):
+                    raise ValueError('invalid value for account type')
+                if account.status is None or not isinstance(account.status,
+                                                            int) or account.status <= 0:
+                    raise ValueError('invalid value for account status')
+                if account.company_name is not None and (not isinstance(
+                        account.company_name, str) or account.company_name == ''):
+                    raise ValueError('invalid string value for account company_name')
+                if account.first_name is not None and (not isinstance(
+                        account.first_name, str) or account.first_name == ''):
+                    raise ValueError('invalid string value for account first_name')
+                if account.last_name is not None and (not isinstance(
+                        account.last_name, str) or account.last_name == ''):
+                    raise ValueError('invalid string value for account last_name')
+            await _sync_objects(preseem_model,
+                                company_uuid,
+                                source,
+                                accounts,
+                                model_accounts,
+                                preseem_model.Account.Create,
+                                preseem_model.Account.Update,
+                                _account_field_map,
+                                noact=noact)
+
         return uuid_map
